@@ -2,7 +2,7 @@ package Email::Address::JP::Mobile;
 use strict;
 use warnings;
 use 5.008000;
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 use Email::Address::Loose;
 
 sub _carriers { qw(
@@ -58,12 +58,13 @@ Email::Address::JP::Mobile - Japanese carrier email class
   $body    = $carrier->send_encoding->encode($body);
   $subject = $carrier->mime_encoding->encode($subject);
 
-or
+or, via Email::Address object
 
   use Email::Address::Loose;
   use Email::Address::JP::Mobile;
   
   my ($email) = Email::Address::Loose->parse('docomo.taro.@docomo.ne.jp');
+  # $email is a Email::Address object
   $email->carrier->is_mobile; # => true
 
 =head1 DESCRIPTION
@@ -77,7 +78,7 @@ Email::Address::JP::Mobile は L<Email::Address> オブジェクトを拡張す
 C<is_mobile($email)> ではなく C<< $email->carrier->is_mobile >> という
 インターフェースである点が違います。
 
-=head1 METHODS
+=head1 USAGE
 
 =over 4
 
@@ -91,25 +92,25 @@ C<is_mobile($email)> ではなく C<< $email->carrier->is_mobile >> という
   $carrier->name; # => "DoCoMo"
   $carrier->carrier_letter; # => "I"
 
-携帯メアドではない場合は Email::Address::JP::Mobile::NonMobile クラスを返します。
+携帯のメールアドレスではないと判断した場合は Email::Address::JP::Mobile::NonMobile クラスを返します。
 
 =item $carrier = $email->carrier()
 
+Email::Address::JP::Mobile は L<Email::Address> オブジェクトに、対応したクラスを返す
+C<carrier()> というメソッドを拡張します。
+
   use Email::Address;
   use Email::Address::JP::Mobile;
   my ($email) = Email::Address->parse('docomo.taro@docomo.ne.jp');
   $email->carrier->carrier_letter; # "I"
 
-Email::Address::JP::Mobile は L<Email::Address> オブジェクトに、対応したクラスを返す
-C<carrier()> というメソッドを拡張します。
-
 ご存知のように日本の携帯は変なアドレスが許可されている期間が長かったので、
 携帯アドレスをパースする可能性があるのであれば L<Email::Address::Loose> を
 利用もしくは併用した方がよいです。
 
 =back
 
-=head1 EMAIL CLASS METHODS
+=head1 CARRIER CLASS METHODS
 
 =over 4
 
@@ -134,9 +135,9 @@ C<carrier()> というメソッドを拡張します。
   $subject = $carrier->mime_encoding->encode($subject);
   $subject = $carrier->mime_encoding->decode($subject);
 
-そのキャリア向けにメールを送信する際、絵文字を含んだ Subject などを MIME encode するためのエンコーディングを返します。
+そのキャリア向けにメールを送信する際、絵文字を含んだ Subject を MIME encode するためのエンコーディングを返します。何を返すかは下記の表を参照してください。
 
-そのキャリアから受け取ったメールの Subject などを MIME decode するためにも利用できます。ただし DoCoMo や SoftBank からの場合絵文字は最初からゲタになり取れないため通常の C<MIME-Header-ISO_2022_JP> 扱いとなります。
+そのキャリアの端末から受信したメールの Subject を MIME decode するためにも利用できます。ただし DoCoMo や SoftBank からの場合絵文字は最初からゲタになり取れないため通常の C<MIME-Header-ISO_2022_JP> 扱いとなります。
 
 =item $carrier->send_encoding()
 
@@ -148,9 +149,9 @@ C<carrier()> というメソッドを拡張します。
 
   $body = $carrier->parse_encoding->decode($body);
 
-そのキャリアから受け取ったメールの絵文字を含んだメール本文を decode するためのオススメなエンコーディングを返します。これはメール本文の C<Content-Type> をチェックしているわけではなく、そのキャリアの場合このエンコーディングで送ってくるだろうというものを返しているだけである点に留意してください。また、DoCoMo や SoftBank からの場合絵文字は最初からゲタになり取れないため普通の C<iso-2022-jp> を返します。
+そのキャリアから受信したメールの絵文字を含んだメール本文を decode するためのオススメなエンコーディングを返します。これはメール本文の C<Content-Type> をチェックしているわけではなく、そのキャリアの場合このエンコーディングで送ってくるだろうというものを返しているだけである点に留意してください。また、DoCoMo や SoftBank からの場合絵文字は最初からゲタになり取れないため普通の C<iso-2022-jp> を返します。
 
-各メソッドが返すエンコーディングは以下のとおりです。（返すのは文字列ではなく L<Encode::Encoding> です）
+上記の各メソッドが返すエンコーディングは以下のとおりです。（返すのは文字列ではなく L<Encode::Encoding> です）
 
              mime_encoding                   send_encoding     parse_encoding
   ------------------------------------------------------------------------------------
@@ -160,7 +161,7 @@ C<carrier()> というメソッドを拡張します。
   WILLCOM    MIME-Header-JP-Mobile-AirH      x-sjis-airh       x-iso-2022-jp-airh
   NonMobile  MIME-Header-ISO_2022_JP         iso-2022-jp       iso-2022-jp
 
-MIME-Header-JP-Mobile-* や x-* のエンコーディングは L<Encode::JP::Mobile> が提供するエンコーディングです。
+MIME-Header-JP-Mobile-* や x-* のエンコーディングは L<Encode::JP::Mobile> （0.27以降）が提供するエンコーディングです。
 
 =back
 
